@@ -211,6 +211,22 @@ class NewBandForm(forms.Form):
         return animal
 
 
+
+class ReservationForm(forms.Form):
+    animal = forms.ModelChoiceField(queryset=Animal.objects.all())
+    date = forms.DateField()
+    description = forms.CharField(widget=forms.Textarea, required=False)
+    entered_by = forms.ModelChoiceField(queryset=User.objects.filter(is_active=True), required=False)
+
+    def clean(self):
+        super().clean()
+        try:
+            self.cleaned_data["status"] = Status.objects.get(name=models.RESERVATION_EVENT_NAME)
+        except ObjectDoesNotExist:
+            raise forms.ValidationError(f"No '{models.RESERVATION_EVENT_NAME}' status type - add one in admin")
+        return self.cleaned_data
+
+
 class SexForm(forms.Form):
     animal = forms.ModelChoiceField(
         queryset=Animal.objects.filter(sex=Animal.UNKNOWN_SEX)
@@ -225,7 +241,7 @@ class SexForm(forms.Form):
         try:
             data["status"] = Status.objects.get(name=models.NOTE_EVENT_NAME)
         except ObjectDoesNotExist:
-            raise forms.ValidationError("No 'note' status type - add one in admin")
+            raise forms.ValidationError(f"No '{models.NOTE_EVENT_NAME}' status type - add one in admin")
         return data
 
     def update_sex(self):
